# Creando Entorno de VS Code Tunnel

## Paso 1: Crear el Namespace
El primer paso es definir un namespace para organizar los recursos de Kubernetes. Utiliza el archivo [`01-namespace.yaml`](../../infrastructure/01-namespace.yaml).

Aplica el archivo con el siguiente comando:
```bash
kubectl apply -f ./infrastructure/01-namespace.yaml
```

---

## Paso 2: Configurar el Persistent Volume y Persistent Volume Claim
Define un volumen persistente y su reclamo utilizando el archivo [`02-pv-pvc.yaml`](../../infrastructure/02-pv-pvc.yaml).

> **Nota:** Dependiendo del servicio de Kubernetes que utilices, la configuración del Persistent Volume Claim puede variar. Aquí hay algunos ejemplos:

### EKS (Amazon Elastic Kubernetes Service)
```yaml
spec:
  storageClassName: gp2
  accessModes:
    - ReadWriteOnce
  resources:
    requests:
      storage: 5Gi
```

### GKS (Google Kubernetes Engine)
```yaml
spec:
  storageClassName: standard
  accessModes:
    - ReadWriteOnce
  resources:
    requests:
      storage: 5Gi
```

### DigitalOcean Kubernetes
```yaml
spec:
  storageClassName: do-block-storage
  accessModes:
    - ReadWriteOnce
  resources:
    requests:
      storage: 5Gi
```

Aplica el archivo con el siguiente comando:
```bash
kubectl apply -f ./infrastructure/02-pv-pvc.yaml
```

---

## Paso 3: Crear el ConfigMap para el Script de Instalación de NVM y Extensiones de VSCode
Define un ConfigMap que contiene un script para instalar Node.js con NVM e instalar Git y otro ConfigMap que contiene un json donde se definen las extensiones a instalar. Utiliza el archivo [`03-configmaps.yaml`](../../infrastructure/03-configmaps.yaml).

Aplica el archivo con el siguiente comando:
```bash
kubectl apply -f ./infrastructure/03-configmaps.yaml
```

---

## Paso 4: Crear el Deployment
Define el deployment para el servidor de VS Code utilizando el archivo [`04-deployment.yaml`](../../infrastructure/04-deployment.yaml).

Aplica el archivo con el siguiente comando:
```bash
kubectl apply -f ./infrastructure/04-deployment.yaml
```

---

## Paso 5: Verificar los Recursos
Verifica que todos los recursos se hayan creado correctamente:
```bash
kubectl get all -n vscode-tunnel
```

> **Nota:** También puedes aplicar todos los archivos desde el directorio raíz del proyecto con el siguiente comando:
> ```bash
> kubectl apply -f ./infrastructure
> ```

Con esto, el entorno de VS Code Tunnel estará configurado y listo para usar.